package com.lqkj.business.service;

import java.util.List;
import java.time.LocalDateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.business.mapper.CmsNewsMapper;
import com.lqkj.business.entity.CmsNews;
import com.lqkj.common.utils.uuid.IdUtils;
/**
 * 信息管理Service业务层处理
 *
 * @author lqkj
 * @date 2023-02-16
 */
@Service
public class CmsNewsService
{
    @Autowired
    private CmsNewsMapper cmsNewsMapper;

    /**
     * 查询信息管理
     *
     * @param newsId 信息管理主键
     * @return 信息管理
     */

    public CmsNews selectCmsNewsByNewsId(String newsId)
    {
        return cmsNewsMapper.selectCmsNewsByNewsId(newsId);
    }

    /**
     * 查询信息管理列表
     *
     * @param cmsNews 信息管理
     * @return 信息管理
     */
    public List<CmsNews> selectCmsNewsList(CmsNews cmsNews)
    {
        return cmsNewsMapper.selectCmsNewsList(cmsNews);
    }

    /**
     * 新增信息管理
     *
     * @param cmsNews 信息管理
     * @return 结果
     */

    public int insertCmsNews(CmsNews cmsNews)
    {
        cmsNews.setCreateTime(LocalDateTime.now());
        cmsNews.setNewsId(IdUtils.simpleUUID());
        return cmsNewsMapper.insertCmsNews(cmsNews);
    }

    /**
     * 修改信息管理
     *
     * @param cmsNews 信息管理
     * @return 结果
     */

    public int updateCmsNews(CmsNews cmsNews)
    {
        cmsNews.setUpdateTime(LocalDateTime.now());
        return cmsNewsMapper.updateCmsNews(cmsNews);
    }

    /**
     * 批量删除信息管理
     *
     * @param newsIds 需要删除的信息管理主键
     * @return 结果
     */

    public int deleteCmsNewsByNewsIds(String[] newsIds)
    {
        return cmsNewsMapper.deleteCmsNewsByNewsIds(newsIds);
    }

    /**
     * 删除信息管理信息
     *
     * @param newsId 信息管理主键
     * @return 结果
     */

    public int deleteCmsNewsByNewsId(String newsId)
    {
        return cmsNewsMapper.deleteCmsNewsByNewsId(newsId);
    }

    public CmsNews selectCmsNewsByCategoryId(Long categoryId){
        return cmsNewsMapper.selectCmsNewsByCategoryId(categoryId);
    }

    public int updateTopStatus(CmsNews cmsNews){
        return cmsNewsMapper.updateTopStatus(cmsNews);
    }

    public int updateCarouselStatus(CmsNews cmsNews){
        return cmsNewsMapper.updateCarouselStatus(cmsNews);
    }

    public int plusViewCount(String newsId){
        return cmsNewsMapper.plusViewCount(newsId);
    }
}
