package com.lqkj.common.core.controller;

import com.github.pagehelper.PageHelper;
import com.lqkj.common.core.model.BaseEntity;
import com.lqkj.common.core.model.LoginUser;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.utils.SecurityUtils;
import com.lqkj.common.utils.StringUtils;
import com.lqkj.common.utils.sql.SqlUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.util.HtmlUtils;

import java.time.LocalDate;

/**
 * web层通用Controller
 */
public class BaseController {
    protected final Logger logger = LoggerFactory.getLogger(this.getClass());

    /**
     * 设置请求分页数据
     */
    protected void startPage(BaseEntity baseEntity){
        if (StringUtils.isNotNull(baseEntity.getPageNum()) && StringUtils.isNotNull(baseEntity.getPageSize())){
            String orderBy = SqlUtil.escapeOrderBySql(baseEntity.convertOrderBy());
            PageHelper.startPage(baseEntity.getPageNum(), baseEntity.getPageSize(), orderBy).setReasonable(baseEntity.getReasonable());
        }
    }
    /**
     * 响应返回结果
     *
     * @param rows 影响行数
     * @return 操作结果
     */
    protected ResultUtil resultByRows(int rows)
    {
        return rows > 0 ? ResultUtil.success() : ResultUtil.error();
    }
    /**
     * 页面跳转
     */
    public String redirect(String url)
    {
        return StringUtils.format("redirect:{}", url);
    }

    /**
     * 获取用户缓存信息
     */
    public LoginUser getLoginUser()
    {
        return SecurityUtils.getLoginUser();
    }

    /**
     * 获取登录用户id
     */
    public String getUserId()
    {
        return getLoginUser().getUserId();
    }

    /**
     * 获取登录部门id
     */
    public Integer getDeptId()
    {
        return getLoginUser().getDeptId();
    }

    /**
     * 获取登录用户名
     */
    public String getUsername()
    {
        return getLoginUser().getUsername();
    }

    /**
     * 获取登录用户昵称
     */
    public String getNickName(){
        return getLoginUser().getUser().getNickName();
    }

    public int getCurrentYear(){
        return LocalDate.now().getYear();
    }
    public int getCurrentMonth(){
        return LocalDate.now().getMonthValue();
    }

    public String htmlUnescape(String data){
        if (StringUtils.isNotEmpty(data)){
            return HtmlUtils.htmlUnescape(data);
        }else{
            return null;
        }
    }
}
