package com.lqkj.common.core.model;

import com.lqkj.common.utils.StringUtils;
import org.springframework.http.HttpStatus;

import java.util.HashMap;

/**
 * Ajax操作消息返回对象
 */
public class ResultUtil extends HashMap<String, Object> {
    /**
     * 状态
     */
    public static final String STATUS_TAG = "status";

    /** 状态码 */
    public static final String CODE_TAG = "code";

    /** 返回内容 */
    public static final String MSG_TAG = "msg";

    /** 数据对象 */
    public static final String DATA_TAG = "data";

    public ResultUtil(){}

    public ResultUtil(Boolean status, int code, String msg, Object data){
        super.put(STATUS_TAG, status);
        super.put(CODE_TAG, code);
        if (StringUtils.isNotEmpty(msg)){
            super.put(MSG_TAG, msg);
        }
        if (StringUtils.isNotNull(data)){
            super.put(DATA_TAG, data);
        }
    }
    public static ResultUtil success(int code, String msg, Object data){
        return new ResultUtil(true, code, msg, data);
    }
    public static ResultUtil success(){
        return ResultUtil.success("操作成功");
    }
    public static ResultUtil success(Object data){
        return ResultUtil.success("操作成功", data);
    }
    public static ResultUtil success(String msg){
        return ResultUtil.success(msg, null);
    }
    public static ResultUtil success(int code){
        return ResultUtil.success(code, "操作成功");
    }
    public static ResultUtil success(String msg, Object data){
        return ResultUtil.success(HttpStatus.OK.value(), msg, data);
    }
    public static ResultUtil success(int code, String msg){
        return ResultUtil.success(code, msg, null);
    }
    public static ResultUtil success(int code, Object data){
        return ResultUtil.success(code, "操作成功", data);
    }

    public static ResultUtil error(int code, String msg, Object data){
        return new ResultUtil(false, code, msg, data);
    }
    public static ResultUtil error(int code, String msg){
        return ResultUtil.error( code, msg, null);
    }
    public static ResultUtil error(String msg, Object data){
        return ResultUtil.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), msg, data);
    }
    public static ResultUtil error(String msg){
        return ResultUtil.error(msg, null);
    }
    public static ResultUtil error(int code){
        return ResultUtil.error(code, null);
    }
    public static ResultUtil error(){
        return ResultUtil.error("操作失败");
    }


    /**
     * 方便链式调用
     *
     * @param key 键
     * @param value 值
     * @return 数据对象
     */
    @Override
    public ResultUtil put(String key, Object value)
    {
        super.put(key, value);
        return this;
    }

}
