package com.lqkj.common.utils;

import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.streaming.SXSSFSheet;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;
import java.io.*;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.Map;

public class xmlUtils {

    /**
     * 将javaBean转换为xml对象
     *
     * @param clazz bean的class
     * @param bean  bean
     * @return xml的string
     */
    public static String parseBeanToXml(Class clazz, Object bean) {
        StringWriter sw = null;
        try {
            JAXBContext jaxbContext = JAXBContext.newInstance(clazz);
            Marshaller jaxbMarshaller = jaxbContext.createMarshaller();
            sw = new StringWriter();
            //该值默认为false,true则不会创建即头信息,即<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
            jaxbMarshaller.setProperty(Marshaller.JAXB_FRAGMENT, false);
            jaxbMarshaller.marshal(bean, sw);
        } catch (JAXBException e) {
            e.printStackTrace();
        }
        return sw.toString();
    }

    /**
     * @param xmlStr 字符串
     * @param c      对象Class类型
     * @return 对象实例
     */
    public static <T> T xml2Object(String xmlStr, Class<T> c) {
        try {
            JAXBContext context = JAXBContext.newInstance(c);
            Unmarshaller unmarshaller = context.createUnmarshaller();
            T t = (T) unmarshaller.unmarshal(new StringReader(xmlStr));
            return t;
        } catch (JAXBException e) {
            e.printStackTrace();
            return null;
        }
    }

    /**
     * xml文件转换字符串
     *
     * @param path
     * @return
     */
    public static String xmlFileToStr(String path) {
        String xmlString = "";
        byte[] strBuffer = null;
        InputStream in = null;
        int flen = 0;
        File xmlfile = new File(path);
        try {
            in = new FileInputStream(xmlfile);
            flen = (int) xmlfile.length();
            strBuffer = new byte[flen];
            in.read(strBuffer, 0, flen);
            in.close();
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            //logger.info("FileNotFound错误" + e.getMessage());
        } catch (IOException e) {
            //logger.info("转换IO错误" + e.getMessage());
            e.printStackTrace();
        }
        xmlString = new String(strBuffer); //构建String时，可用byte[]类型，
        //logger.info("xml文件转换后的字符串：" + xmlString);
        return xmlString;
    }

    /**
     * 关闭表格
     *
     * @param os       数据流
     * @param workbook 表格类
     */
    public static void closeWorkBook(OutputStream os, SXSSFWorkbook workbook) {
        try {
            workbook.write(os);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                os.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        workbook.dispose();
    }

    /**
     * 关闭表格
     *
     * @param os       数据流
     * @param workbook 表格类
     */
    public static void closeWorkBook(OutputStream os, Workbook workbook) {
        try {
            workbook.write(os);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                os.close();
                workbook.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    /**
     * 输出一个错误信息的表格
     *
     * @param os      数据流
     * @param message 错误信息
     */
    public static void wrongWorkBook(OutputStream os, String message) {
        SXSSFWorkbook workbook = new SXSSFWorkbook();
        SXSSFSheet sheet = workbook.createSheet("出现错误");
        Row rootRow = sheet.createRow(0);
        rootRow.createCell(0).setCellValue(message);

        try {
            workbook.write(os);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                os.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        workbook.dispose();
    }

    public static void setCell(Row row, int position, String value, CellStyle style) {
        row.setHeightInPoints(26f);
        row.createCell(position).setCellValue(value);
        row.getCell(position).setCellStyle(style);
    }

    public static void setCell(Row row, int position, Integer value, CellStyle style) {
        row.setHeightInPoints(26f);
        row.createCell(position).setCellValue(value);
        row.getCell(position).setCellStyle(style);
    }

    public static void setCell(Row row, int position, Long value, CellStyle style) {
        row.setHeightInPoints(26f);
        row.createCell(position).setCellValue(value);
        row.getCell(position).setCellStyle(style);
    }

    public static String getTime(Long millisecond) {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH-mm", Locale.CHINA);
        Date date = new Date(millisecond);
        return format.format(date);
    }

    public static String getCellValue(Cell cell) {
        if (cell == null || cell.toString().equals("")) return "";
        DecimalFormat df = new DecimalFormat("0");
        String result = "";
        switch (cell.getCellType()) {
            case STRING:
                result = cell.getStringCellValue();
                break;
            case NUMERIC:
                result = df.format(cell.getNumericCellValue());
                break;
        }
        if (cell.getCellType().equals(CellType.NUMERIC) && DateUtil.isCellDateFormatted(cell))
            result = TimeUtils.getTimeString(cell.getDateCellValue().getTime(), "yyyy-MM-dd HH:mm:ss");
        return result;
    }

    public static String getValue(Map<String, Object> map, String key) {
        if (map.get(key) == null) return "";
        else return map.get(key).toString();
    }
}
