package com.lqkj.framework.config;

import okio.BufferedSink;
import okio.Okio;
import org.apache.commons.lang.StringUtils;
import org.springframework.core.io.ClassPathResource;
import org.yaml.snakeyaml.Yaml;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.LinkedHashMap;
import java.util.Scanner;

public class PropertyDeploy {
    public static final String PropertyDirPath = "./config";
    public static final String PropertyFilePath = PropertyDirPath + "/application.yml";

    /**
     * 查询文件是否存在
     *
     * @return
     */
    private boolean isPropertyFileExist() {
        return Files.exists(Paths.get(PropertyFilePath));
    }

    /**
     * 数据库链接询问
     */
    private void inputDataBaseConfig() {
        Scanner scanner = new Scanner(System.in);

        System.out.println("请输入数据库IP(默认127.0.0.1):");
        String ip = scanner.nextLine();

        System.out.println("请输入数据库端口(默认5432):");
        String port = scanner.nextLine();

        System.out.println("请输入数据库名称:");
        String dbName = scanner.nextLine();

        System.out.println("请输入数据库用户名(默认postgres):");
        String userName = scanner.nextLine();

        System.out.println("请输入数据库密码:");
        String passWord = scanner.nextLine();

        System.out.println("请输入Redis的IP(默认127.0.0.1):");
        String redisIP = scanner.nextLine();

        System.out.println("请输入Redis端口(默认6379):");
        String redisPort = scanner.nextLine();

        System.out.println("请输入Redis密码(默认空):");
        String redisPassword = scanner.nextLine();


        createConfigureFile(ip, port, dbName, userName, passWord, redisIP, redisPort, redisPassword);
    }

    /**
     * 创建配置文件
     */
    public void createConfigureFile(String ip, String port, String dbName, String userName, String passWord,
                                    String redisIP, String redisPort, String redisPassword) {
        if (StringUtils.isEmpty(ip)){
            ip = "127.0.0.1";
        }
        if (StringUtils.isEmpty(port)){
            port = "5432";
        }
        if (StringUtils.isEmpty(redisIP)){
            redisIP = "127.0.0.1";
        }
        if (StringUtils.isEmpty(redisPort)){
            redisPort = "6379";
        }
        if (StringUtils.isEmpty(redisPassword)){
            redisPassword = "";
        }
        if (StringUtils.isEmpty(userName)){
            userName = "postgres";
        }
        File applicationFile = new File(PropertyFilePath);

        ClassPathResource resource = new ClassPathResource("application-install.yml");

        Yaml yaml = new Yaml();

        BufferedSink sink = null;

        InputStream inputStream = null;

        try {
            Files.createDirectories(Paths.get(PropertyDirPath));

            Files.createFile(Paths.get(PropertyFilePath));

            inputStream = resource.getInputStream();

            LinkedHashMap<String, LinkedHashMap> application = (LinkedHashMap<String, LinkedHashMap>) yaml.load(inputStream);

            LinkedHashMap<String, Object> dateSource = (LinkedHashMap<String, Object>) application.get("spring").get("datasource");

            dateSource.put("url", "jdbc:postgresql://" + ip + ":" + port + "/" + dbName);
            dateSource.put("username", userName);
            dateSource.put("password", passWord);

            LinkedHashMap<String, Object> redisDateSource = (LinkedHashMap<String, Object>) (application.get("spring").get("redis"));
            redisDateSource.put("host", redisIP);
            redisDateSource.put("port", redisPort);
            redisDateSource.put("password", redisPassword);
            sink = Okio.buffer(Okio.sink(applicationFile));

            sink.write(yaml.dump(application).getBytes());

            sink.flush();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if (sink != null) {
                    sink.close();
                }
                if (inputStream != null) {
                    inputStream.close();
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /**
     * 部署文件
     */
    public void deploy() {
        if (!isPropertyFileExist()) {
            inputDataBaseConfig();
        }
    }
}
