package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.ParkingLot;
import com.lqkj.info.service.ParkingLotService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 停车场信息Controller
 * 
 * @author lqkj
 * @date 2024-12-23
 */
@Api(tags = {"停车场信息"})
@RestController
@RequestMapping("/info/parkingLot")
public class ParkingLotController extends BaseController
{
    @Autowired
    private ParkingLotService parkingLotService;

    /**
     * 查询停车场信息列表
     */
    @ApiOperation("查询停车场信息列表")
    @PreAuthorize("@ss.hasPermi('info:parkingLot:list')")
    @GetMapping("/list")
    public ResultUtil list(ParkingLot parkingLot)
    {
        startPage( parkingLot);
        PageInfo<ParkingLot> pageInfo = new PageInfo<>(parkingLotService.selectParkingLotList(parkingLot));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出停车场信息列表
     */
    @ApiOperation("导出停车场信息列表")
    @PreAuthorize("@ss.hasPermi('info:parkingLot:export')")
    @Log(title = "停车场信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(ParkingLot parkingLot)
    {
        List<ParkingLot> list = parkingLotService.selectParkingLotList(parkingLot);
        ExcelUtil<ParkingLot> util = new ExcelUtil<ParkingLot>(ParkingLot.class);
        return util.exportExcel(list, "停车场信息数据");
    }

    /**
     * 获取停车场信息详细信息
     */
    @ApiOperation("获取停车场信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:parkingLot:query')")
    @GetMapping(value = "/{parkingId}")
    public ResultUtil getInfo(@PathVariable("parkingId") Integer parkingId)
    {
        return ResultUtil.success(parkingLotService.selectParkingLotByParkingId(parkingId));
    }

    /**
     * 新增停车场信息
     */
    @ApiOperation("新增停车场信息")
    @PreAuthorize("@ss.hasPermi('info:parkingLot:add')")
    @Log(title = "停车场信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody ParkingLot parkingLot)
    {
        return resultByRows(parkingLotService.insertParkingLot(parkingLot));
    }

    /**
     * 修改停车场信息
     */
    @ApiOperation("修改停车场信息")
    @PreAuthorize("@ss.hasPermi('info:parkingLot:edit')")
    @Log(title = "停车场信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody ParkingLot parkingLot)
    {
        return resultByRows(parkingLotService.updateParkingLot(parkingLot));
    }

    /**
     * 删除停车场信息
     */
    @ApiOperation("删除停车场信息")
    @PreAuthorize("@ss.hasPermi('info:parkingLot:remove')")
    @Log(title = "停车场信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{parkingIds}")
    public ResultUtil remove(@PathVariable Integer[] parkingIds)
    {
        return resultByRows(parkingLotService.deleteParkingLotByParkingIds(parkingIds));
    }
}