package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.StationInfo;
import com.lqkj.info.service.StationInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 站点信息Controller
 * 
 * @author lqkj
 * @date 2024-11-14
 */
@Api(tags = {"站点信息"})
@RestController
@RequestMapping("/info/stationInfo")
public class StationInfoController extends BaseController
{
    @Autowired
    private StationInfoService stationInfoService;

    /**
     * 查询站点信息列表
     */
    @ApiOperation("查询站点信息列表")
    @PreAuthorize("@ss.hasPermi('info:stationInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(StationInfo stationInfo)
    {
        startPage( stationInfo);
        PageInfo<StationInfo> pageInfo = new PageInfo<>(stationInfoService.selectStationInfoList(stationInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出站点信息列表
     */
    @ApiOperation("导出站点信息列表")
    @PreAuthorize("@ss.hasPermi('info:stationInfo:export')")
    @Log(title = "站点信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(StationInfo stationInfo)
    {
        List<StationInfo> list = stationInfoService.selectStationInfoList(stationInfo);
        ExcelUtil<StationInfo> util = new ExcelUtil<StationInfo>(StationInfo.class);
        return util.exportExcel(list, "站点信息数据");
    }

    /**
     * 获取站点信息详细信息
     */
    @ApiOperation("获取站点信息详细信息")
    @PreAuthorize("@ss.hasPermi('info:stationInfo:query')")
    @GetMapping(value = "/{stationId}")
    public ResultUtil getInfo(@PathVariable("stationId") Integer stationId)
    {
        return ResultUtil.success(stationInfoService.selectStationInfoByStationId(stationId));
    }

    /**
     * 新增站点信息
     */
    @ApiOperation("新增站点信息")
    @PreAuthorize("@ss.hasPermi('info:stationInfo:add')")
    @Log(title = "站点信息", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody StationInfo stationInfo)
    {
        return resultByRows(stationInfoService.insertStationInfo(stationInfo));
    }

    /**
     * 修改站点信息
     */
    @ApiOperation("修改站点信息")
    @PreAuthorize("@ss.hasPermi('info:stationInfo:edit')")
    @Log(title = "站点信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody StationInfo stationInfo)
    {
        return resultByRows(stationInfoService.updateStationInfo(stationInfo));
    }

    /**
     * 删除站点信息
     */
    @ApiOperation("删除站点信息")
    @PreAuthorize("@ss.hasPermi('info:stationInfo:remove')")
    @Log(title = "站点信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{stationIds}")
    public ResultUtil remove(@PathVariable Integer[] stationIds)
    {
        return resultByRows(stationInfoService.deleteStationInfoByStationIds(stationIds));
    }
}