package com.lqkj.info.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.info.entity.TrafficInfo;
import com.lqkj.info.service.TrafficInfoService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 交通对象Controller
 * 
 * @author lqkj
 * @date 2024-11-14
 */
@Api(tags = {"交通对象"})
@RestController
@RequestMapping("/info/trafficInfo")
public class TrafficInfoController extends BaseController
{
    @Autowired
    private TrafficInfoService trafficInfoService;

    /**
     * 查询交通对象列表
     */
    @ApiOperation("查询交通对象列表")
    @PreAuthorize("@ss.hasPermi('info:trafficInfo:list')")
    @GetMapping("/list")
    public ResultUtil list(TrafficInfo trafficInfo)
    {
        startPage( trafficInfo);
        PageInfo<TrafficInfo> pageInfo = new PageInfo<>(trafficInfoService.selectTrafficInfoList(trafficInfo));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出交通对象列表
     */
    @ApiOperation("导出交通对象列表")
    @PreAuthorize("@ss.hasPermi('info:trafficInfo:export')")
    @Log(title = "交通对象", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(TrafficInfo trafficInfo)
    {
        List<TrafficInfo> list = trafficInfoService.selectTrafficInfoList(trafficInfo);
        ExcelUtil<TrafficInfo> util = new ExcelUtil<TrafficInfo>(TrafficInfo.class);
        return util.exportExcel(list, "交通对象数据");
    }

    /**
     * 获取交通对象详细信息
     */
    @ApiOperation("获取交通对象详细信息")
    @PreAuthorize("@ss.hasPermi('info:trafficInfo:query')")
    @GetMapping(value = "/{trafficId}")
    public ResultUtil getInfo(@PathVariable("trafficId") Integer trafficId)
    {
        return ResultUtil.success(trafficInfoService.selectTrafficInfoByTrafficId(trafficId));
    }

    /**
     * 新增交通对象
     */
    @ApiOperation("新增交通对象")
    @PreAuthorize("@ss.hasPermi('info:trafficInfo:add')")
    @Log(title = "交通对象", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody TrafficInfo trafficInfo)
    {
        return resultByRows(trafficInfoService.insertTrafficInfo(trafficInfo));
    }

    /**
     * 修改交通对象
     */
    @ApiOperation("修改交通对象")
    @PreAuthorize("@ss.hasPermi('info:trafficInfo:edit')")
    @Log(title = "交通对象", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody TrafficInfo trafficInfo)
    {
        return resultByRows(trafficInfoService.updateTrafficInfo(trafficInfo));
    }

    /**
     * 删除交通对象
     */
    @ApiOperation("删除交通对象")
    @PreAuthorize("@ss.hasPermi('info:trafficInfo:remove')")
    @Log(title = "交通对象", businessType = BusinessType.DELETE)
	@DeleteMapping("/{trafficIds}")
    public ResultUtil remove(@PathVariable Integer[] trafficIds)
    {
        return resultByRows(trafficInfoService.deleteTrafficInfoByTrafficIds(trafficIds));
    }
}