package com.lqkj.info.service;

import java.util.List;

import com.lqkj.info.mapper.ShiftPersonnelMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.info.mapper.ParkingLotMapper;
import com.lqkj.info.entity.ParkingLot;
import com.lqkj.common.utils.uuid.IdUtils;
/**
 * 停车场信息Service业务层处理
 * 
 * @author lqkj
 * @date 2024-12-23
 */
@Service
public class ParkingLotService
{
    @Autowired
    private ParkingLotMapper parkingLotMapper;

    @Autowired
    private ShiftPersonnelMapper shiftPersonnelMapper;

    /**
     * 查询停车场信息
     * 
     * @param parkingId 停车场信息主键
     * @return 停车场信息
     */
    
    public ParkingLot selectParkingLotByParkingId(Integer parkingId)
    {
        return parkingLotMapper.selectParkingLotByParkingId(parkingId);
    }

    /**
     * 查询停车场信息列表
     * 
     * @param parkingLot 停车场信息
     * @return 停车场信息
     */
    public List<ParkingLot> selectParkingLotList(ParkingLot parkingLot)
    {
        List<ParkingLot> parkingLots = parkingLotMapper.selectParkingLotList(parkingLot);
        parkingLots.forEach(p -> {
            String personnelName = shiftPersonnelMapper.selectPersonnelName(p.getParkingId());
            p.setPersonnelName(personnelName);
        });
        return parkingLots;
    }

    /**
     * 新增停车场信息
     * 
     * @param parkingLot 停车场信息
     * @return 结果
     */
    
    public int insertParkingLot(ParkingLot parkingLot)
    {
        return parkingLotMapper.insertParkingLot(parkingLot);
    }

    /**
     * 修改停车场信息
     * 
     * @param parkingLot 停车场信息
     * @return 结果
     */
    
    public int updateParkingLot(ParkingLot parkingLot)
    {
        return parkingLotMapper.updateParkingLot(parkingLot);
    }

    /**
     * 批量删除停车场信息
     * 
     * @param parkingIds 需要删除的停车场信息主键
     * @return 结果
     */
    
    public int deleteParkingLotByParkingIds(Integer[] parkingIds)
    {
        return parkingLotMapper.deleteParkingLotByParkingIds(parkingIds);
    }

    /**
     * 删除停车场信息信息
     * 
     * @param parkingId 停车场信息主键
     * @return 结果
     */
    
    public int deleteParkingLotByParkingId(Integer parkingId)
    {
        return parkingLotMapper.deleteParkingLotByParkingId(parkingId);
    }
}