package com.lqkj.supporting.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.supporting.entity.ResourcesType;
import com.lqkj.supporting.service.ResourcesTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 资源类型Controller
 *
 * @author lqkj
 * @date 2025-05-07
 */
@Api(tags = {"资源类型"})
@RestController
@RequestMapping("/supporting/type")
public class ResourcesTypeController extends BaseController
{
    @Autowired
    private ResourcesTypeService resourcesTypeService;

    /**
     * 查询资源类型列表
     */
    @ApiOperation("查询资源类型列表")
    @PreAuthorize("@ss.hasPermi('supporting:type:list')")
    @GetMapping("/list")
    public ResultUtil list(ResourcesType resourcesType)
    {
        startPage( resourcesType);
        PageInfo<ResourcesType> pageInfo = new PageInfo<>(resourcesTypeService.selectResourcesTypeList(resourcesType));
        return ResultUtil.success(pageInfo);
    }
    @ApiOperation("查询所有资源类型列表")
    @GetMapping("/listAll")
    public ResultUtil list() {
        return ResultUtil.success(resourcesTypeService.selectResourcesTypeList(new ResourcesType()));
    }

    /**
     * 导出资源类型列表
     */
    @ApiOperation("导出资源类型列表")
    @PreAuthorize("@ss.hasPermi('supporting:type:export')")
    @Log(title = "资源类型", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(ResourcesType resourcesType)
    {
        List<ResourcesType> list = resourcesTypeService.selectResourcesTypeList(resourcesType);
        ExcelUtil<ResourcesType> util = new ExcelUtil<ResourcesType>(ResourcesType.class);
        return util.exportExcel(list, "资源类型数据");
    }

    /**
     * 获取资源类型详细信息
     */
    @ApiOperation("获取资源类型详细信息")
    @PreAuthorize("@ss.hasPermi('supporting:type:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(resourcesTypeService.selectResourcesTypeByTypeId(typeId));
    }

    /**
     * 新增资源类型
     */
    @ApiOperation("新增资源类型")
    @PreAuthorize("@ss.hasPermi('supporting:type:add')")
    @Log(title = "资源类型", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody ResourcesType resourcesType)
    {
        return resultByRows(resourcesTypeService.insertResourcesType(resourcesType));
    }

    /**
     * 修改资源类型
     */
    @ApiOperation("修改资源类型")
    @PreAuthorize("@ss.hasPermi('supporting:type:edit')")
    @Log(title = "资源类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody ResourcesType resourcesType)
    {
        return resultByRows(resourcesTypeService.updateResourcesType(resourcesType));
    }

    /**
     * 删除资源类型
     */
    @ApiOperation("删除资源类型")
    @PreAuthorize("@ss.hasPermi('supporting:type:remove')")
    @Log(title = "资源类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(resourcesTypeService.deleteResourcesTypeByTypeIds(typeIds));
    }
}
