package com.lqkj.system.controller;


import com.lqkj.ApiVersion;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.config.LingWeiConfig;
import com.lqkj.common.constant.UserConstants;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.LoginUser;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import com.lqkj.common.utils.SecurityUtils;
import com.lqkj.common.utils.StringUtils;
import com.lqkj.common.utils.file.FileUploadUtils;
import com.lqkj.system.entity.SysUser;
import com.lqkj.system.service.SysUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.Map;

/**
 * 个人信息 业务处理
 * 
 * @author lh
 */
@Api(tags = {"个人信息处理"})
@RestController
@RequestMapping("/" + ApiVersion.V1 + "/system/user/profile")
public class SysProfileController extends BaseController
{
    @Autowired
    private SysUserService userService;


    /**
     * 个人信息
     */
    @ApiOperation("个人信息")
    @GetMapping
    public ResultUtil profile()
    {
        SysUser user = userService.selectUserById(getLoginUser().getUser().getUserId());
        ResultUtil ajax = ResultUtil.success(user);
        ajax.put("roleGroup", userService.selectUserRoleGroup(user.getUserName()));
        ajax.put("postGroup", userService.selectUserPostGroup(user.getUserName()));
        return ajax;
    }

    /**
     * 修改用户
     */
    @ApiOperation("修改用户信息")
    @Log(title = "个人信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil updateProfile(@RequestBody SysUser user)
    {
        if (StringUtils.isNotEmpty(user.getPhonenumber())
                && UserConstants.NOT_UNIQUE.equals(userService.checkPhoneUnique(user)))
        {
            return ResultUtil.error("修改用户'" + user.getUserName() + "'失败，手机号码已存在");
        }
        if (StringUtils.isNotEmpty(user.getEmail())
                && UserConstants.NOT_UNIQUE.equals(userService.checkEmailUnique(user)))
        {
            return ResultUtil.error("修改用户'" + user.getUserName() + "'失败，邮箱账号已存在");
        }
        LoginUser loginUser = getLoginUser();
        SysUser sysUser = loginUser.getUser();
        user.setUserId(sysUser.getUserId());
        user.setPassword(null);
        if (userService.updateUserProfile(user) > 0)
        {
            return ResultUtil.success();
        }
        return ResultUtil.error("修改个人信息异常，请联系管理员");
    }

    /**
     * 重置密码
     */
    @ApiOperation("重置密码")
    @Log(title = "个人信息", businessType = BusinessType.UPDATE)
    @PutMapping("/updatePwd")
    public ResultUtil updatePwd(@RequestBody Map<String, String> param)
    {
        LoginUser loginUser = getLoginUser();
        String userName = loginUser.getUsername();
        String password = loginUser.getPassword();
        if (!SecurityUtils.matchesPassword(param.get("oldPassword"), password))
        {
            return ResultUtil.error("修改密码失败，旧密码错误");
        }
        if (SecurityUtils.matchesPassword(param.get("newPassword"), password))
        {
            return ResultUtil.error("新密码不能与旧密码相同");
        }
        if (userService.resetUserPwd(userName, SecurityUtils.encryptPassword(param.get("newPassword"))) > 0)
        {
            return ResultUtil.success();
        }
        return ResultUtil.error("修改密码异常，请联系管理员");
    }

    /**
     * 头像上传
     */
    @ApiOperation("头像上传")
    @Log(title = "用户头像", businessType = BusinessType.UPDATE)
    @PostMapping("/avatar")
    public ResultUtil avatar(@RequestParam("avatarfile") MultipartFile file) throws IOException
    {
        if (!file.isEmpty())
        {
            LoginUser loginUser = getLoginUser();
            String avatar = FileUploadUtils.upload(LingWeiConfig.getAvatarPath(), file);
            if (userService.updateUserAvatar(loginUser.getUsername(), avatar))
            {
                ResultUtil ajax = ResultUtil.success();
                ajax.put("imgUrl", avatar);
                return ajax;
            }
        }
        return ResultUtil.error("上传图片异常，请联系管理员");
    }
}
