package com.lqkj.system.service;

import java.util.List;
import java.time.LocalDateTime;
import java.util.Map;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.lqkj.common.constant.UserConstants;
import com.lqkj.common.core.model.BaseEntity;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.utils.StringUtils;
import com.lqkj.common.utils.sql.SqlUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.lqkj.system.mapper.SysApiConfigMapper;
import com.lqkj.system.entity.SysApiConfig;
import com.lqkj.common.utils.uuid.IdUtils;
/**
 * 接口配置Service业务层处理
 * 
 * @author lqkj
 * @date 2023-02-06
 */
@Service
public class SysApiConfigService
{
    @Autowired
    private SysApiConfigMapper sysApiConfigMapper;

    /**
     * 查询接口配置
     * 
     * @param id 接口配置主键
     * @return 接口配置
     */
    
    public SysApiConfig selectSysApiConfigById(String id)
    {
        return sysApiConfigMapper.selectSysApiConfigById(id);
    }

    /**
     * 查询接口配置列表
     * 
     * @param sysApiConfig 接口配置
     * @return 接口配置
     */
    public List<SysApiConfig> selectSysApiConfigList(SysApiConfig sysApiConfig)
    {
        return sysApiConfigMapper.selectSysApiConfigList(sysApiConfig);
    }

    /**
     * 新增接口配置
     * 
     * @param sysApiConfig 接口配置
     * @return 结果
     */
    
    public int insertSysApiConfig(SysApiConfig sysApiConfig)
    {
        sysApiConfig.setCreateTime(LocalDateTime.now());
        sysApiConfig.setId(IdUtils.simpleUUID());
        return sysApiConfigMapper.insertSysApiConfig(sysApiConfig);
    }

    /**
     * 修改接口配置
     * 
     * @param sysApiConfig 接口配置
     * @return 结果
     */
    
    public int updateSysApiConfig(SysApiConfig sysApiConfig)
    {
        sysApiConfig.setUpdateTime(LocalDateTime.now());
        return sysApiConfigMapper.updateSysApiConfig(sysApiConfig);
    }

    /**
     * 批量删除接口配置
     * 
     * @param ids 需要删除的接口配置主键
     * @return 结果
     */
    
    public int deleteSysApiConfigByIds(String[] ids)
    {
        return sysApiConfigMapper.deleteSysApiConfigByIds(ids);
    }

    /**
     * 校验路由唯一性
     * @param sysApiConfig
     * @return
     */
    public String checkRoutePathUnique(SysApiConfig sysApiConfig)
    {
        int count = sysApiConfigMapper.checkRoutePathUnique(sysApiConfig);
        if (count > 0)
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 删除接口配置信息
     * 
     * @param id 接口配置主键
     * @return 结果
     */
    
    public int deleteSysApiConfigById(String id)
    {
        return sysApiConfigMapper.deleteSysApiConfigById(id);
    }

    /**
     * 通用查询接口
     * @param routePath
     * @param param
     * @return
     */
    public ResultUtil selectData(String routePath, Map<String, Object> param) {
        SysApiConfig sysApiConfig  = sysApiConfigMapper.selectSysApiConfigByRoutePath(routePath);
        if (sysApiConfig != null){
            String sqlStr = sysApiConfig.getSqlStr();
            if (param != null){
                for(Map.Entry<String,Object> entry:param.entrySet()){
                    sqlStr = sqlStr.replaceAll("@" +entry.getKey(), entry.getValue().toString());
                }
            }
            if (StringUtils.isEmpty(sqlStr)){
                return ResultUtil.error("接口查询SQL未配置");
            }
            if (param != null && param.containsKey("page")
                    && StringUtils.isNotNull(param.get("page"))
                    && StringUtils.isNotNull(param.get("pageSize"))
                    && sysApiConfig.getReturnDataType().equals("List")) {//有分页参数需要分页
                BaseEntity baseEntity = new BaseEntity();
                baseEntity.setPageSize(Integer.parseInt(param.get("pageSize").toString()));
                baseEntity.setPageNum(Integer.parseInt(param.get("page").toString()));
                if (param.containsKey("orderByColumn") && StringUtils.isNotNull(param.get("orderByColumn"))){ //有排序字段需要排序
                    baseEntity.setOrderByColumn(param.get("orderByColumn").toString());
                }
                String orderBy = SqlUtil.escapeOrderBySql(baseEntity.convertOrderBy());
                PageHelper.startPage(baseEntity.getPageNum(), baseEntity.getPageSize(), orderBy).setReasonable(baseEntity.getReasonable());
                PageInfo pageInfo =  new PageInfo(sysApiConfigMapper.findListData(sqlStr));
                return ResultUtil.success(pageInfo);
            }else{
                if (sysApiConfig.getReturnDataType().equals("List")){
                    return ResultUtil.success(sysApiConfigMapper.findListData(sqlStr));
                }else{
                    return ResultUtil.success(sysApiConfigMapper.findMapData(sqlStr));
                }
            }
        }else{
            return ResultUtil.error("接口未配置");
        }
    }
}
