package com.lqkj.type.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.type.entity.HouseType;
import com.lqkj.type.service.HouseTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 户型信息：house_typeController
 * 
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"户型信息：house_type"})
@RestController
@RequestMapping("/type/houseType")
public class HouseTypeController extends BaseController
{
    @Autowired
    private HouseTypeService houseTypeService;

    /**
     * 查询户型信息：house_type列表
     */
    @ApiOperation("查询户型信息：house_type列表")
    @PreAuthorize("@ss.hasPermi('type:houseType:list')")
    @GetMapping("/list")
    public ResultUtil list(HouseType houseType)
    {
        startPage( houseType);
        PageInfo<HouseType> pageInfo = new PageInfo<>(houseTypeService.selectHouseTypeList(houseType));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出户型信息：house_type列表
     */
    @ApiOperation("导出户型信息：house_type列表")
    @PreAuthorize("@ss.hasPermi('type:houseType:export')")
    @Log(title = "户型信息：house_type", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(HouseType houseType)
    {
        List<HouseType> list = houseTypeService.selectHouseTypeList(houseType);
        ExcelUtil<HouseType> util = new ExcelUtil<HouseType>(HouseType.class);
        return util.exportExcel(list, "户型信息：house_type数据");
    }

    /**
     * 获取户型信息：house_type详细信息
     */
    @ApiOperation("获取户型信息：house_type详细信息")
    @PreAuthorize("@ss.hasPermi('type:houseType:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(houseTypeService.selectHouseTypeByTypeId(typeId));
    }

    /**
     * 新增户型信息：house_type
     */
    @ApiOperation("新增户型信息：house_type")
    @PreAuthorize("@ss.hasPermi('type:houseType:add')")
    @Log(title = "户型信息：house_type", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody HouseType houseType)
    {
        return resultByRows(houseTypeService.insertHouseType(houseType));
    }

    /**
     * 修改户型信息：house_type
     */
    @ApiOperation("修改户型信息：house_type")
    @PreAuthorize("@ss.hasPermi('type:houseType:edit')")
    @Log(title = "户型信息：house_type", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody HouseType houseType)
    {
        return resultByRows(houseTypeService.updateHouseType(houseType));
    }

    /**
     * 删除户型信息：house_type
     */
    @ApiOperation("删除户型信息：house_type")
    @PreAuthorize("@ss.hasPermi('type:houseType:remove')")
    @Log(title = "户型信息：house_type", businessType = BusinessType.DELETE)
	@DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(houseTypeService.deleteHouseTypeByTypeIds(typeIds));
    }
}