package com.lqkj.type.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.type.entity.RoomType;
import com.lqkj.type.service.RoomTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 房间类别Controller
 * 
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"房间类别"})
@RestController
@RequestMapping("/type/roomType")
public class RoomTypeController extends BaseController
{
    @Autowired
    private RoomTypeService roomTypeService;

    /**
     * 查询房间类别列表
     */
    @ApiOperation("查询房间类别列表")
    @PreAuthorize("@ss.hasPermi('type:roomType:list')")
    @GetMapping("/list")
    public ResultUtil list(RoomType roomType)
    {
        startPage( roomType);
        PageInfo<RoomType> pageInfo = new PageInfo<>(roomTypeService.selectRoomTypeList(roomType));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出房间类别列表
     */
    @ApiOperation("导出房间类别列表")
    @PreAuthorize("@ss.hasPermi('type:roomType:export')")
    @Log(title = "房间类别", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(RoomType roomType)
    {
        List<RoomType> list = roomTypeService.selectRoomTypeList(roomType);
        ExcelUtil<RoomType> util = new ExcelUtil<RoomType>(RoomType.class);
        return util.exportExcel(list, "房间类别数据");
    }

    /**
     * 获取房间类别详细信息
     */
    @ApiOperation("获取房间类别详细信息")
    @PreAuthorize("@ss.hasPermi('type:roomType:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(roomTypeService.selectRoomTypeByTypeId(typeId));
    }

    /**
     * 新增房间类别
     */
    @ApiOperation("新增房间类别")
    @PreAuthorize("@ss.hasPermi('type:roomType:add')")
    @Log(title = "房间类别", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody RoomType roomType)
    {
        return resultByRows(roomTypeService.insertRoomType(roomType));
    }

    /**
     * 修改房间类别
     */
    @ApiOperation("修改房间类别")
    @PreAuthorize("@ss.hasPermi('type:roomType:edit')")
    @Log(title = "房间类别", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody RoomType roomType)
    {
        return resultByRows(roomTypeService.updateRoomType(roomType));
    }

    /**
     * 删除房间类别
     */
    @ApiOperation("删除房间类别")
    @PreAuthorize("@ss.hasPermi('type:roomType:remove')")
    @Log(title = "房间类别", businessType = BusinessType.DELETE)
	@DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(roomTypeService.deleteRoomTypeByTypeIds(typeIds));
    }
}