package com.lqkj.type.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.lqkj.common.annotation.Log;
import com.lqkj.common.core.controller.BaseController;
import com.lqkj.common.core.model.ResultUtil;
import com.lqkj.common.enums.BusinessType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.lqkj.type.entity.TrafficType;
import com.lqkj.type.service.TrafficTypeService;
import com.lqkj.common.utils.poi.ExcelUtil;
import com.github.pagehelper.PageInfo;

/**
 * 交通类型Controller
 *
 * @author lqkj
 * @date 2024-11-11
 */
@Api(tags = {"交通类型"})
@RestController
@RequestMapping("/type/trafficType")
public class TrafficTypeController extends BaseController
{
    @Autowired
    private TrafficTypeService trafficTypeService;

    /**
     * 查询交通类型列表
     */
    @ApiOperation("查询交通类型列表")
    @PreAuthorize("@ss.hasPermi('type:trafficType:list')")
    @GetMapping("/list")
    public ResultUtil list(TrafficType trafficType)
    {
        startPage( trafficType);
        PageInfo<TrafficType> pageInfo = new PageInfo<>(trafficTypeService.selectTrafficTypeList(trafficType));
        return ResultUtil.success(pageInfo);
    }

    /**
     * 导出交通类型列表
     */
    @ApiOperation("导出交通类型列表")
    @PreAuthorize("@ss.hasPermi('type:trafficType:export')")
    @Log(title = "交通类型", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public ResultUtil export(TrafficType trafficType)
    {
        List<TrafficType> list = trafficTypeService.selectTrafficTypeList(trafficType);
        ExcelUtil<TrafficType> util = new ExcelUtil<TrafficType>(TrafficType.class);
        return util.exportExcel(list, "交通类型数据");
    }

    /**
     * 获取交通类型详细信息
     */
    @ApiOperation("获取交通类型详细信息")
    @PreAuthorize("@ss.hasPermi('type:trafficType:query')")
    @GetMapping(value = "/{typeId}")
    public ResultUtil getInfo(@PathVariable("typeId") Integer typeId)
    {
        return ResultUtil.success(trafficTypeService.selectTrafficTypeByTypeId(typeId));
    }

    /**
     * 新增交通类型
     */
    @ApiOperation("新增交通类型")
    @PreAuthorize("@ss.hasPermi('type:trafficType:add')")
    @Log(title = "交通类型", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultUtil add(@RequestBody TrafficType trafficType)
    {
        return resultByRows(trafficTypeService.insertTrafficType(trafficType));
    }

    /**
     * 修改交通类型
     */
    @ApiOperation("修改交通类型")
    @PreAuthorize("@ss.hasPermi('type:trafficType:edit')")
    @Log(title = "交通类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultUtil edit(@RequestBody TrafficType trafficType)
    {
        return resultByRows(trafficTypeService.updateTrafficType(trafficType));
    }

    /**
     * 删除交通类型
     */
    @ApiOperation("删除交通类型")
    @PreAuthorize("@ss.hasPermi('type:trafficType:remove')")
    @Log(title = "交通类型", businessType = BusinessType.DELETE)
    @DeleteMapping("/{typeIds}")
    public ResultUtil remove(@PathVariable Integer[] typeIds)
    {
        return resultByRows(trafficTypeService.deleteTrafficTypeByTypeIds(typeIds));
    }
}